==> haskell-http-types-0.9-4-armv7h.pkg.tar.xz: usr/share/haskell/haskell-http-types/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-types
version: 0.9
id: http-types-0.9-26f1bedc2b9255e48a8e673fef6095b1
key: httpt_9pxk76irFTK7gBmHJvVaaW
license: BSD3
copyright: (C) 2011 Aristid Breitkreuz
maintainer: aristidb@googlemail.com
homepage: https://github.com/aristidb/http-types
synopsis: Generic HTTP types for Haskell (for both client and server code).
description:
    Generic HTTP types for Haskell (for both client and server code).
category: Network, Web
author: Aristid Breitkreuz, Michael Snoyman
exposed: True
exposed-modules:
    Network.HTTP.Types Network.HTTP.Types.Header
    Network.HTTP.Types.Method Network.HTTP.Types.QueryLike
    Network.HTTP.Types.Status Network.HTTP.Types.URI
    Network.HTTP.Types.Version
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/http-types-0.9
library-dirs: /usr/lib/ghc-7.10.3/site-local/http-types-0.9
data-dir: /usr/share/arm-linux-ghc-7.10.3/http-types-0.9
hs-libraries: HShttp-types-0.9-9pxk76irFTK7gBmHJvVaaW
depends:
    array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    blaze-builder-0.4.0.1-adef087994cafeb1970772b79d5f710a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    case-insensitive-1.2.0.5-0be5e2a885602c48fdae255d4ef6b04b
    text-1.2.1.3-6c3c87c392cdf2c29fca1c10bbf7250b
haddock-interfaces: /usr/share/doc/haskell-http-types/html/http-types.haddock
haddock-html: /usr/share/doc/haskell-http-types/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-types-0.9-5-armv7h.pkg.tar.xz: usr/share/haskell/haskell-http-types/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-types
version: 0.9
id: http-types-0.9-d392878af9c5e1b1993961dc71a9e177
key: httpt_3Bf1bEHnPYIAJ2rfQRlloD
license: BSD3
copyright: (C) 2011 Aristid Breitkreuz
maintainer: aristidb@googlemail.com
homepage: https://github.com/aristidb/http-types
synopsis: Generic HTTP types for Haskell (for both client and server code).
description:
    Generic HTTP types for Haskell (for both client and server code).
category: Network, Web
author: Aristid Breitkreuz, Michael Snoyman
exposed: True
exposed-modules:
    Network.HTTP.Types Network.HTTP.Types.Header
    Network.HTTP.Types.Method Network.HTTP.Types.QueryLike
    Network.HTTP.Types.Status Network.HTTP.Types.URI
    Network.HTTP.Types.Version
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/http-types-0.9
library-dirs: /usr/lib/ghc-7.10.3/site-local/http-types-0.9
data-dir: /usr/share/arm-linux-ghc-7.10.3/http-types-0.9
hs-libraries: HShttp-types-0.9-3Bf1bEHnPYIAJ2rfQRlloD
depends:
    array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    blaze-builder-0.4.0.1-3daa45cd3be9618b289586d273c59e36
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    case-insensitive-1.2.0.5-6669cd7a393ccedc4f66c0a01b6f0e2f
    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
haddock-interfaces: /usr/share/doc/haskell-http-types/html/http-types.haddock
haddock-html: /usr/share/doc/haskell-http-types/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
